﻿#include "StdAfx.h"
#include "MessageBox.h"
#include "SimpleTextShape.h"
#include "WindowScriptletPlugin.h"

UINT_PTR MessageBox::Call(LPCTSTR lpText, LPCTSTR lpCaption, UINT uType, HWND hWndParent )
{
	SimpleMapDataContext dataContext;

	CString text = lpText;
	CString nodename = _T("tip_messagebox");
	int pos = text.Find(L"|");
	if( pos > 0 )
	{
		nodename = _T("tip_messagebox_bold");
		CString title = text.Left(pos);
		dataContext.SetProperty(_T("body_title"), CComVariant(title));
		text = text.Mid(pos+1);
	}
	TiXmlElement* pNode = Application::LoadLayoutNode(nodename);
	if (pNode == NULL) return IDCANCEL;

	
	dataContext.SetProperty(_T("title_text"), CComVariant(lpCaption));
	dataContext.SetProperty(_T("body_text"), CComVariant(text));
	dataContext.SetProperty(_T("message_type"), CComVariant(uType));

	return CWindowScriptletPlugin::DoModal(pNode, hWndParent, NULL, &dataContext);
}



//
// BTS-117 101022 황현동
// 시작페이지가 변경됨을 알리는 메시지박스
//
UINT_PTR MessageBox::CallStartPage(CString strStartPageUrl, HWND hWndParent)
{
	TiXmlElement* pNode = Application::LoadLayoutNode(_T("tip_messagebox_startpage"));
	if (pNode == NULL) return IDCANCEL;

	SimpleMapDataContext dataContext;
	dataContext.SetProperty(_T("title_text"), CComVariant(_T("네이버 툴즈 알림")));
	dataContext.SetProperty(_T("start_page_url"), CComVariant(strStartPageUrl));

	return CWindowScriptletPlugin::DoModal(pNode, hWndParent, NULL, &dataContext);
}



//
// BTS-117 101022 황현동
// 검색공급자가 변경됨을 알리는 메시지박스
//
UINT_PTR MessageBox::CallDefaultSearch(CString strDefaultSearch, HWND hWndParent)
{
	TiXmlElement* pNode = Application::LoadLayoutNode(_T("tip_messagebox_defaultsearch"));
	if (pNode == NULL) return IDCANCEL;

	SimpleMapDataContext dataContext;
	dataContext.SetProperty(_T("title_text"), CComVariant(_T("네이버 툴즈 알림")));
	dataContext.SetProperty(_T("default_search"), CComVariant(strDefaultSearch));

	return CWindowScriptletPlugin::DoModal(pNode, hWndParent, NULL, &dataContext);
}

UINT_PTR MessageBox::Call(LPCTSTR lpText, LPCTSTR lpCaption, LPCTSTR layoutNode, UINT uType, HWND hWndParent)
{
	TiXmlElement* pNode = Application::LoadLayoutNode(layoutNode);
	if (pNode == NULL) return IDCANCEL;

	SimpleMapDataContext dataContext;
	dataContext.SetProperty(_T("title_text"), CComVariant(lpCaption));
	dataContext.SetProperty(_T("body_text"), CComVariant(lpText));
	dataContext.SetProperty(_T("message_type"), CComVariant(uType));

	return CWindowScriptletPlugin::DoModal(pNode, hWndParent, NULL, &dataContext);
}
UINT_PTR MessageBox::Call(CScriptletDialog* dialog, TiXmlElement* pNode, LPCTSTR lpText, LPCTSTR lpCaption, UINT uType, HWND hWndParent )
{
// 	TiXmlElement* pNode = Application::LoadLayoutNode(_T("tip_messagebox"));
// 	if (pNode == NULL) return IDCANCEL;

	SimpleMapDataContext dataContext;
	dataContext.SetProperty(_T("title_text"), CComVariant(lpCaption));
	dataContext.SetProperty(_T("body_text"), CComVariant(lpText));
	dataContext.SetProperty(_T("message_type"), CComVariant(uType));

	return CWindowScriptletPlugin::DoModal(dialog, pNode, hWndParent, NULL, &dataContext);
}
CScriptletDialog* MessageBox::Create(TiXmlElement** ppNode, LPCTSTR layoutNodeName)
{
	if (layoutNodeName)
		*ppNode = Application::LoadLayoutNode(layoutNodeName);
	else
		*ppNode = Application::LoadLayoutNode(_T("tip_messagebox"));
	if (*ppNode == NULL) return NULL;
	return CWindowScriptletPlugin::CretateDialog(*ppNode);
}

REGISTER_CONVERTER_CREATOR(_T("msgtype2confirmvisible"), MessageType2ConfirmVisible);
CComVariant MessageType2ConfirmVisible::Convert(CComVariant* src)
{
	UINT uType = src->uintVal;
	BOOL bVisible = (uType == MB_OK); 

	CComVariant convertValue(bVisible ? SCRIPTLET_TRUE_VALUE : SCRIPTLET_FALSE_VALUE);
	return convertValue;
}
REGISTER_CONVERTER_CREATOR(_T("msgtype2yesvisible"), MessageType2YesVisible);
CComVariant MessageType2YesVisible::Convert(CComVariant* src)
{
	UINT uType = src->uintVal;
	BOOL bVisible = (uType == MB_YESNO) || (uType == MB_YESNOCANCEL); 

	CComVariant convertValue(bVisible ? SCRIPTLET_TRUE_VALUE : SCRIPTLET_FALSE_VALUE);
	return convertValue;
}
REGISTER_CONVERTER_CREATOR(_T("msgtype2novisible"), MessageType2NoVisible);
CComVariant MessageType2NoVisible::Convert(CComVariant* src)
{
	UINT uType = src->uintVal;
	BOOL bVisible = (uType == MB_YESNO) || (uType == MB_YESNOCANCEL); 

	CComVariant convertValue(bVisible ? SCRIPTLET_TRUE_VALUE : SCRIPTLET_FALSE_VALUE);
	return convertValue;	
}
REGISTER_CONVERTER_CREATOR(_T("msgtype2cancelvisible"), MessageType2CancelVisible);
CComVariant MessageType2CancelVisible::Convert(CComVariant* src)
{
	UINT uType = src->uintVal;
	BOOL bVisible = (uType == MB_YESNOCANCEL); 

	CComVariant convertValue(bVisible ? SCRIPTLET_TRUE_VALUE : SCRIPTLET_FALSE_VALUE);
	return convertValue;
}
REGISTER_COMPONENT_CREATOR(_T("MessageBox"), MessageBox);
void MessageBox::OnCreateContent(LPARAM lParam)
{
	//본문에 따라 메시지 상자의 크기를 다시 계산한다.
	CSimpleTextShape* body_text = dynamic_cast<CSimpleTextShape*>(m_rootContainer.FindName(_T("body_text")));
	if (body_text != NULL)
	{
		body_text->SetEnableWordbreak();

		CString text = body_text->GetText();
		body_text->SetText(_T(""));

		CSize pre_sizePreferred;
		body_text->GetOrginPreferredSize(&pre_sizePreferred);

		body_text->SetText(text);
		CSize sizePreferred;
		sizePreferred.cx = pre_sizePreferred.cx;
		sizePreferred.cy = 0;
		body_text->GetOrginPreferredSize(&sizePreferred);

		int dy = sizePreferred.cy - pre_sizePreferred.cy;
		if (dy > 0)
		{			
			CRect rcClient;
			this->GetClientRect(&rcClient);
			this->SetWindowPos(NULL, 0, 0, rcClient.Width(), rcClient.Height() + dy, SWP_NOMOVE | SWP_NOACTIVATE);
		}
	}
}